package com.ruoyi.app.service;

import java.util.List;
import com.ruoyi.app.model.EntranceBatch;

/**
 * 入场批次Service接口
 * 
 * @author coede
 * @date 2025-03-19
 */
public interface IEntranceBatchService 
{
    /**
     * 查询入场批次
     * 
     * @param id 入场批次主键
     * @return 入场批次
     */
    public EntranceBatch selectEntranceBatchById(Long id);

    /**
     * 查询入场批次列表
     * 
     * @param entranceBatch 入场批次
     * @return 入场批次集合
     */
    public List<EntranceBatch> selectEntranceBatchList(EntranceBatch entranceBatch);


    public List<EntranceBatch> selectEntranceBatchList1(EntranceBatch entranceBatch);

    /**
     * 完工报告逻辑修正
     */
    public List<EntranceBatch> selectEntranceBatchList2(EntranceBatch entranceBatch);

    /**
     * 校验检疫证号是否唯一
     *
     * @param entranceBatch 入场批次
     * @return 结果
     */
    public boolean checkAnimalCertNoUnique(EntranceBatch entranceBatch);

    /**
     * 新增入场批次
     * 
     * @param entranceBatch 入场批次
     * @return 结果
     */
    public int insertEntranceBatch(EntranceBatch entranceBatch);

    /**
     * 修改入场批次
     * 
     * @param entranceBatch 入场批次
     * @return 结果
     */
    public int updateEntranceBatch(EntranceBatch entranceBatch);

    /**
     * 批量删除入场批次
     * 
     * @param ids 需要删除的入场批次主键集合
     * @return 结果
     */
    public int deleteEntranceBatchByIds(Long[] ids);

    /**
     * 删除入场批次信息
     * 
     * @param id 入场批次主键
     * @return 结果
     */
    public int deleteEntranceBatchById(Long id);

    /**
     * 获取最近一条记录
     * @return 结果
     */
    public EntranceBatch selectLatelyEntrance();
}
